# Best-Profanity

`best-profanity` uses a linear SVM model trained on 200k human-labeled samples of clean and
profane text strings. Its model is simple but surprisingly effective, meaning
**`best-profanity` is both robust and extremely performant**.
    